import * as tslint from 'tslint';
import * as typescript from 'typescript';
export interface RunConfiguration {
    readonly jsEnable?: boolean;
    readonly rulesDirectory?: string | string[];
    readonly configFile?: string;
    readonly ignoreDefinitionFiles?: boolean;
    readonly exclude?: string | string[];
    readonly validateWithDefaultConfig?: boolean;
    readonly nodePath?: string;
    readonly packageManager?: 'npm' | 'yarn';
    readonly traceLevel?: 'verbose' | 'normal';
    readonly workspaceFolderPath?: string;
}
export interface RunResult {
    readonly lintResult: tslint.LintResult;
    readonly warnings: string[];
    readonly workspaceFolderPath?: string;
    readonly configFilePath?: string;
}
export declare class TsLintRunner {
    private trace;
    private readonly tslintPath2Library;
    private readonly document2LibraryCache;
    private readonly globalPackageManagerPath;
    private readonly configCache;
    constructor(trace: (data: string) => void);
    runTsLint(filePath: string, contents: string | typescript.Program, configuration: RunConfiguration): RunResult;
    /**
     * Filter failures for the given document
     */
    filterProblemsForFile(filePath: string, failures: tslint.RuleFailure[]): tslint.RuleFailure[];
    onConfigFileChange(_tsLintFilePath: string): void;
    getNonOverlappingReplacements(failures: tslint.RuleFailure[]): tslint.Replacement[];
    private getReplacements;
    private getReplacement;
    private sortFailures;
    private loadLibrary;
    private getGlobalPackageManagerPath;
    private doRun;
    private getConfiguration;
    private fileIsExcluded;
    private traceConfigurationFile;
    private resolveTsLint;
}
